@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: horde/index.php,v 2.105.4.3 2005/03/02 07:10:35 chuck Exp $
+ * $Horde: horde/index.php,v 2.105.4.3.2.2 2006/07/29 16:49:37 jan Exp $
  *
  * Copyright 1999-2005 Charles J. Hagenbuch <chuck@horde.org>
  * Copyright 1999-2005 Jon Parise <jon@horde.org>
@@ -34,6 +34,33 @@ if ($browser->isMobile()) {
 }
 
 $main_page = Util::getFormData('url');
+
+// Break up the requested URL in $main_page and run some sanity checks
+// on it to prevent phishing and XSS attacks. If any of the checks
+// fail, $main_page will be set to null.
+if (!empty($main_page)) {
+    // Mute errors in case of unparseable URLs
+    $req = @parse_url($main_page);
+
+    // We assume that any valid redirect URL will be in the same
+    // cookie domain. This helps prevent rogue off-site Horde installs
+    // from mimicking the real server.
+    if (isset($req['host'])) {
+        $qcookiedom = preg_quote($conf['cookie']['domain']);
+        if (!preg_match('/' . $qcookiedom . '$/', $req['host'])) {
+            $main_page = null;
+        }
+    }
+
+    // Protocol whitelist: If the URL is fully qualified, make sure it
+    // is either http or https.
+    $allowed_protocols = array('http', 'https');
+    if (empty($req['scheme']) ||
+        !in_array($req['scheme'], $allowed_protocols)) {
+        $main_page = null;
+    }
+}
+
 if (!$main_page) {
     $main_page = Horde::initialPage();
 }
