@@ -6,7 +6,7 @@ require_once 'Horde/History.php';
 /**
  * The Group:: class provides the Horde groups system.
  *
- * $Horde: framework/Group/Group.php,v 1.67.2.6 2005/07/07 18:12:17 selsky Exp $
+ * $Horde: framework/Group/Group.php,v 1.67.2.6.2.1 2005/12/17 21:25:21 chuck Exp $
  *
  * Copyright 1999-2005 Stephane Huther <shuther@bigfoot.com>
  * Copyright 2001-2005 Chuck Hagenbuch <chuck@horde.org>
@@ -267,6 +267,19 @@ class Group {
         return $this->_datatree->getParents($group);
     }
 
+    /**
+     * Get a list of parents all the way up to the root object for $group.
+     *
+     * @param integer $gid  The id of the group.
+     *
+     * @return array  A flat list of all of the parents of $group,
+     *                hashed in $id => $name format.
+     */
+    function getGroupParentList($gid)
+    {
+        return $this->_datatree->getParentList($gid);
+    }
+
     /**
      * Get a list of every group, in the format cid => groupname.
      *
