@@ -47,7 +47,7 @@ define('MIME_STRING', 2);
 /**
  * The MIME:: class provides methods for dealing with MIME standards.
  *
- * $Horde: framework/MIME/MIME.php,v 1.139.4.3 2005/01/15 05:14:37 chuck Exp $
+ * $Horde: framework/MIME/MIME.php,v 1.139.4.12 2005/09/15 03:29:53 slusarz Exp $
  *
  * Copyright 1999-2005 Chuck Hagenbuch <chuck@horde.org>
  *
@@ -63,7 +63,7 @@ class MIME {
     /**
      * A listing of the allowed MIME types.
      *
-     * @var array $mime_types
+     * @var array
      */
     var $mime_types = array(
         TYPETEXT => 'text',
@@ -80,7 +80,7 @@ class MIME {
     /**
      * A listing of the allowed MIME encodings.
      *
-     * @var array $mime_encodings
+     * @var array
      */
     var $mime_encodings = array(
         ENC7BIT => '7bit',
@@ -94,15 +94,13 @@ class MIME {
     /**
      * Filter for RFC822.
      *
-     * @var array $rfc822_filter
+     * @var string
      */
     var $rfc822_filter = "()<>@,;:\\\"[]\1\2\3\4\5\6\7\10\11\12\13\14\15\16\17\20\21\22\23\24\25\26\27\30\31\32\33\34\35\36\37\177";
 
     /**
      * Determines if a string contains 8-bit characters.
      *
-     * @access public
-     *
      * @param string $string  The string to check.
      *
      * @return boolean  True if it does, false if it doesn't.
@@ -115,8 +113,6 @@ class MIME {
     /**
      * Encodes a string containing non-ASCII characters according to RFC 2047.
      *
-     * @access public
-     *
      * @param string $text     The text to encode.
      * @param string $charset  The character set of the text.
      *
@@ -186,8 +182,6 @@ class MIME {
      * Encodes a line via quoted-printable encoding.
      * Wraps lines at 76 characters.
      *
-     * @access public
-     *
      * @param string $text  The text to encode.
      * @param string $eol   The EOL sequence to use.
      *
@@ -243,8 +237,6 @@ class MIME {
      * This differs from MIME::encode() because it keeps email addresses legal,
      * only encoding the personal information.
      *
-     * @access public
-     *
      * @param string $text       The email addresses to encode.
      * @param string $charset    The character set of the text.
      * @param string $defserver  The default domain to append to mailboxes.
@@ -263,8 +255,11 @@ class MIME {
         require_once 'Mail/RFC822.php';
         $parser = &new Mail_RFC822();
         $addr_arr = $parser->parseAddressList($text, $defserver, false, false);
-        $text = '';
+        if (is_a($addr_arr, 'PEAR_Error')) {
+            return $addr_arr;
+        }
 
+        $text = '';
         if (is_array($addr_arr)) {
             foreach ($addr_arr as $addr) {
                 if (empty($addr->personal)) {
@@ -289,7 +284,21 @@ class MIME {
     /**
      * Decodes an RFC 2047-encoded string.
      *
-     * @access public
+     * @param string $string      The text to decode.
+     * @param string $to_charset  The charset that the text should be decoded
+     *                            to.
+     *
+     * @return string  The decoded text.
+     */
+    function decode($string, $to_charset = null)
+    {
+        return stripslashes(MIME::_decode($string, $to_charset));
+    }
+
+    /**
+     * Decodes an RFC 2047-encoded string.
+     *
+     * @private
      *
      * @param string $string      The text to decode.
      * @param string $to_charset  The charset that the text should be decoded
@@ -298,7 +307,7 @@ class MIME {
      * @return string  The decoded text, or the original string if it was not
      *                 encoded.
      */
-    function decode($string, $to_charset = null)
+    function _decode($string, $to_charset)
     {
         if (($pos = strpos($string, '=?')) === false) {
             return $string;
@@ -342,15 +351,14 @@ class MIME {
         switch ($encoding) {
         case 'Q':
         case 'q':
-            $encoded_text = str_replace('_', '%20', $encoded_text);
-            $encoded_text = str_replace('=', '%', $encoded_text);
-            $decoded = urldecode($encoded_text);
+            $encoded_text = str_replace('_', ' ', $encoded_text);
+            $decoded = preg_replace('/=([0-9a-f]{2})/ie', 'chr(0x\1)', $encoded_text);
             $decoded = String::convertCharset($decoded, $charset, $to_charset);
             break;
 
         case 'B':
         case 'b':
-            $decoded = urldecode(base64_decode($encoded_text));
+            $decoded = base64_decode($encoded_text);
             $decoded = String::convertCharset($decoded, $charset, $to_charset);
             break;
 
@@ -359,14 +367,12 @@ class MIME {
             break;
         }
 
-        return $preceding . $decoded . MIME::decode($rest, $to_charset);
+        return $preceding . $decoded . MIME::_decode($rest, $to_charset);
     }
 
     /**
      * Decodes an RFC 2231-encoded string.
      *
-     * @access public
-     *
      * @param string $string   The entire string to decode, including the
      *                         parameter name.
      * @param string $charset  The charset that the text should be decoded to.
@@ -425,8 +431,6 @@ class MIME {
      * If an email address has no personal information, get rid of any angle
      * brackets (<>) around it.
      *
-     * @access public
-     *
      * @param string $address  The address to trim.
      *
      * @return string  The trimmed address.
@@ -445,8 +449,6 @@ class MIME {
     /**
      * Builds an RFC 822 compliant email address.
      *
-     * @access public
-     *
      * @param string $mailbox   Mailbox name.
      * @param string $host      Domain name of mailbox's host.
      * @param string $personal  Personal name phrase.
@@ -482,8 +484,6 @@ class MIME {
      * Explodes a RFC 822 string, ignoring a delimiter if preceded by a "\"
      * character, or if delimiter is inside single or double quotes.
      *
-     * @access public
-     *
      * @param string $str        The RFC 822 string.
      * @param string $delimiter  The delimter.
      *
@@ -495,15 +495,18 @@ class MIME {
         $match = 0;
         $quotes = array('"', "'");
         $in_quote = null;
+        $in_group = false;
         $prev = null;
 
         if (empty($str)) {
             return array($str);
         }
 
-        if (in_array($str[0], $quotes)) {
-            $in_quote = $str[0];
-        } elseif ($str[0] == $delimiter) {
+        if (in_array($str{0}, $quotes)) {
+            $in_quote = $str{0};
+        } elseif ($str{0} == ':') {
+            $in_group = true;
+        } elseif ($str{0} == $delimiter) {
             $arr[] = '';
             $match = 1;
         }
@@ -518,8 +521,16 @@ class MIME {
                         $in_quote = $char;
                     }
                 }
-            } elseif (($char == $delimiter) &&
-                      ($prev !== '\\') &&
+            } elseif ($in_group) {
+                if ($char == ';') {
+                    $arr[] = substr($str, $match, $i - $match + 1);
+                    $match = $i + 1;
+                    $in_group = false;
+                }
+            } elseif ($char == ':') {
+                $in_group = true;
+            } elseif ($char == $delimiter &&
+                      $prev !== '\\' &&
                       is_null($in_quote)) {
                 $arr[] = substr($str, $match, $i - $match);
                 $match = $i + 1;
@@ -546,8 +557,6 @@ class MIME {
      *   $object->host     = The host the mailbox is on ("example.com")
      * </pre>
      *
-     * @access public
-     *
      * @param stdClass $ob   The address object to be turned into a string.
      * @param mixed $filter  A user@example.com style bare address to ignore.
      *                       Either single string or an array of strings.  If
@@ -600,8 +609,6 @@ class MIME {
      * Takes an array of address objects, as returned by imap_headerinfo(),
      * for example, and passes each of them through MIME::addrObject2String().
      *
-     * @access public
-     *
      * @param array $addresses  The array of address objects.
      * @param mixed $filter     A user@example.com style bare address to
      *                          ignore.  If any address matches $filter, it
@@ -638,8 +645,6 @@ class MIME {
     /**
      * Returns the bare address.
      *
-     * @access public
-     *
      * @param string $address    The address string.
      * @param string $defserver  The default domain to append to mailboxes.
      * @param boolean $multiple  Should we return multiple results?
@@ -652,15 +657,21 @@ class MIME {
     {
         $addressList = array();
 
-        /* Don't use built-in IMAP function (imap_rfc822_parse_adrlist)
-         * because it doesn't parse distribution lists properly. */
-        require_once 'Mail/RFC822.php';
-        $parser = &new Mail_RFC822();
-        $from = $parser->parseAddressList($address, $defserver, false, false);
+        /* Use built-in IMAP function only if available and if not parsing
+         * distribution lists because it doesn't parse distribution lists
+         * properly. */
+        if (Util::extensionExists('imap') && strpos($address, ':') === false) {
+            $from = imap_rfc822_parse_adrlist($address, $defserver);
+        } else {
+            require_once 'Mail/RFC822.php';
+            $parser = &new Mail_RFC822();
+            $from = $parser->parseAddressList($address, $defserver, false, false);
+        }
 
         foreach ($from as $entry) {
             if (isset($entry->mailbox) &&
-                ($entry->mailbox != 'undisclosed-recipients')) {
+                $entry->mailbox != 'undisclosed-recipients' &&
+                $entry->mailbox != 'UNEXPECTED_DATA_AFTER_ADDRESS') {
                 if (isset($entry->host)) {
                     $addressList[] = $entry->mailbox . '@' . $entry->host;
                 } else {
@@ -700,6 +711,7 @@ class MIME {
         }
 
         if (strcspn($str, $filter) != strlen($str)) {
+            $str = str_replace('\"', '"', $str);
             return '"' . str_replace('"', '\\"', str_replace('\\', '\\\\', $str)) . '"';
         } else {
             return $str;
@@ -709,8 +721,6 @@ class MIME {
     /**
      * Returns the MIME type for the given input.
      *
-     * @access public
-     *
      * @param mixed $input     Either the MIME code or type string.
      * @param integer $format  If MIME_CODE, return code.
      *                         If MIME_STRING, returns lowercase string.
@@ -725,8 +735,6 @@ class MIME {
     /**
      * Returns the MIME encoding for the given input.
      *
-     * @access public
-     *
      * @param mixed $input     Either the MIME code or encoding string.
      * @param integer $format  If MIME_CODE, return code.
      *                         If MIME_STRING, returns lowercase string.
@@ -785,8 +793,6 @@ class MIME {
      * Generates a Message-ID string conforming to RFC 2822 [3.6.4] and the
      * standards outlined in 'draft-ietf-usefor-message-id-01.txt'.
      *
-     * @access public
-     *
      * @param string  A message ID string.
      */
     function generateMessageID()
@@ -809,8 +815,6 @@ class MIME {
      * compromise is to put each parameter on a separate line and chop it
      * only if it is longer than 998 characters.
      *
-     * @access public
-     *
      * @param string $header  The header name.
      * @param string $text    The text of the header field.
      * @param string $eol     The EOL string to use.
