@@ -1,9 +1,9 @@
 <?php
 /**
- * The MIME_Viewer_deb class renders out lists of files in Debian
- * packages by using the dpkg tool to query the package.
+ * The MIME_Viewer_deb class renders out lists of files in Debian packages by
+ * using the dpkg tool to query the package.
  *
- * $Horde: framework/MIME/MIME/Viewer/deb.php,v 1.11.10.5 2005/07/03 05:04:10 selsky Exp $
+ * $Horde: framework/MIME/MIME/Viewer/deb.php,v 1.11.10.5.2.1 2005/11/22 09:00:27 jan Exp $
  *
  * Copyright 1999-2005 Anil Madhavapeddy <anil@recoil.org>
  *
@@ -44,7 +44,7 @@ class MIME_Viewer_deb extends MIME_Viewer {
         }
         pclose($fh);
 
-        return '<pre>' . htmlentities($data) . '</pre>';
+        return '<pre>' . htmlspecialchars($data) . '</pre>';
     }
 
     /**
