@@ -3,31 +3,28 @@
 require_once dirname(__FILE__) . '/source.php';
 
 /**
- * The MIME_Viewer_srchighlite class renders out various content
- * in HTML format by using Source-highlight.
+ * The MIME_Viewer_srchighlite class renders out various content in HTML
+ * format by using Source-highlight.
  *
- * Web C Plus plus: http://www.gnu.org/software/src-highlite/
+ * Source-highlight: http://www.gnu.org/software/src-highlite/
  *
- * $Horde: framework/MIME/MIME/Viewer/srchighlite.php,v 1.14.10.1 2005/01/03 12:19:06 jan Exp $
+ * $Horde: framework/MIME/MIME/Viewer/srchighlite.php,v 1.14.10.3 2005/07/03 05:04:10 selsky Exp $
  *
  * Copyright 2003-2005 Mike Cochrane <mike@graftonhall.co.nz>
  *
- * See the enclosed file COPYING for license information (LGPL). If you
- * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
+ * See the enclosed file COPYING for license information (LGPL). If you did
+ * not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Mike Cochrane <mike@graftonhall.co.nz>
- * @version $Revision: 1.14.10.1 $
  * @since   Horde 3.0
  * @package Horde_MIME_Viewer
  */
 class MIME_Viewer_srchighlite extends MIME_Viewer_source {
 
     /**
-     * Render out the currently set contents using Web C Plus Plus.
+     * Render out the currently set contents using Source-highlight
      *
-     * @access public
-     *
-     * @param optional array $params  Any parameters the Viewer may need.
+     * @param array $params  Any parameters the viewer may need.
      *
      * @return string  The rendered contents.
      */
@@ -99,7 +96,7 @@ class MIME_Viewer_srchighlite extends MIME_Viewer_source {
 
         if (!$inline) {
             $html .= Util::bufferOutput('require', $registry->get('templates', 'horde') . '/common-header.inc');
-            $html .= "<div style='background-color:white'>";
+            $html .= '<div style="background-color:white">';
         }
 
         /* Execute Source-Highlite. */
@@ -109,7 +106,7 @@ class MIME_Viewer_srchighlite extends MIME_Viewer_source {
         @fclose($fp);
         unlink($tmpout);
 
-        $html .= $this->lineNumber($this->lineNumber($data));
+        $html .= $this->lineNumber($data);
 
         if (!$inline) {
             $html .= '</div>';
