@@ -19,7 +19,7 @@
  * The table structure for the SessionHandler can be found in
  * horde/scripts/sql/horde_sessionhandler.sql.
  *
- * $Horde: framework/SessionHandler/SessionHandler/mysql.php,v 1.16.12.7 2005/06/26 04:28:31 chuck Exp $
+ * $Horde: framework/SessionHandler/SessionHandler/mysql.php,v 1.16.12.7.2.1 2005/10/31 20:23:57 jan Exp $
  *
  * Copyright 2002-2005 Mike Cochrane <mike@graftonhall.co.nz>
  * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
@@ -165,10 +165,15 @@ class SessionHandler_mysql extends SessionHandler {
         /* Execute the query. */
         $result = @mysql_query($query, $this->_db);
         if (!$result) {
+            $result = @mysql_query('ROLLBACK', $this->_db);
+            $result = @mysql_query('SET AUTOCOMMIT=1', $this->_db);
             Horde::logMessage('Failed to delete session (id = ' . $id . ')', __FILE__, __LINE__, PEAR_LOG_ERR);
             return false;
         }
 
+        $result = @mysql_query('COMMIT', $this->_db);
+        $result = @mysql_query('SET AUTOCOMMIT=1', $this->_db);
+
         return true;
     }
 
