@@ -13,7 +13,7 @@ define('HORDE_ERROR_DRIVER_CONFIG', 2);
 /**
  * The Util:: class provides generally useful methods of different kinds.
  *
- * $Horde: framework/Util/Util.php,v 1.384.6.9 2005/08/24 14:04:38 selsky Exp $
+ * $Horde: framework/Util/Util.php,v 1.384.6.9.2.1 2006/03/28 12:33:32 jan Exp $
  *
  * Copyright 1999-2005 Chuck Hagenbuch <chuck@horde.org>
  * Copyright 1999-2005 Jon Parise <jon@horde.org>
@@ -71,7 +71,7 @@ class Util {
         if (func_num_args() == 0) {
             return false;
         }
-        $eval = false;
+        $include = false;
         $args = func_get_args();
         $function = array_shift($args);
         if (is_array($function)) {
@@ -82,17 +82,31 @@ class Util {
                   ($function == 'include_once') ||
                   ($function == 'require') ||
                   ($function == 'require_once')) {
-            $eval = true;
-        } elseif (!function_exists($function) &&
-                  ($function != 'eval')) {
+            $include = true;
+        } elseif (!function_exists($function)) {
             return false;
         }
 
         ob_start();
-        if ($eval) {
-            eval($function . " '" . implode(',', $args) . "';");
-        } elseif ($function == 'eval') {
-            eval($args[0]);
+        if ($include) {
+            $file = implode(',', $args);
+            switch ($function) {
+            case 'include':
+                include $file;
+                break;
+
+            case 'include_once':
+                include_once $file;
+                break;
+
+            case 'require':
+                require $file;
+                break;
+
+            case 'require_once':
+                require_once $file;
+                break;
+            }
         } else {
             call_user_func_array($function, $args);
         }
