@@ -1,4 +1,3 @@
-
 <?php
 
 include_once 'Log.php';
@@ -26,12 +25,11 @@ define('IMSP_NO_CONTINUATION_RESPONSE', 'Did not receive expexted command contin
 /**
  * The Net_IMSP class provides a common interface to an IMSP server .
  *
- * Required parameters:
- * =========================
- * 'server' -- Hostname of IMSP server.
- * 'port'   -- Port of IMSP server.
+ * Required parameters:<pre>
+ *   'server'  Hostname of IMSP server.
+ *   'port'    Port of IMSP server.</pre>
  *
- * $Horde: framework/Net_IMSP/IMSP.php,v 1.13.10.6 2005/03/11 02:24:22 mrubinsk Exp $
+ * $Horde: framework/Net_IMSP/IMSP.php,v 1.13.10.13.2.1 2005/12/17 19:14:25 chuck Exp $
  *
  * Copyright 2003-2005 Michael Rubinsky <mrubinsk@horde.org>
  *
@@ -45,26 +43,31 @@ class Net_IMSP {
 
     /**
      * String containing name/IP address of imsp host.
-     * @var string $imsp_server
+     *
+     * @var string
      */
     var $imsp_server                = 'localhost';
 
     /**
      * String containing port for imsp server.
-     * @var string $imsp_port
+     *
+     * @var string
      */
     var $imsp_port                  = '406';
 
     /**
      * Boolean to set if we should write to a log, if one is set up.
-     * @var boolean $logEnabled
+     *
+     * @var boolean
      */
     var $logEnabled                 = true;
     /**
-     * String buffer containing the last raw NO or BAD response
-     * from the server.
+     * String buffer containing the last raw NO or BAD response from the
+     * server.
+     *
+     * @var string
      */
-     var $lastRawError              = '';
+    var $lastRawError              = '';
 
 
     // Private Declarations
@@ -81,7 +84,6 @@ class Net_IMSP {
     /**
      * Constructor function.
      *
-     * @access public
      * @param array $params Hash containing server parameters.
      */
     function Net_IMSP($params)
@@ -100,7 +102,6 @@ class Net_IMSP {
      * Initialization function to be called after object is returned.  This
      * allows errors to occur and not break the script.
      *
-     * @access public
      * @return mixed  True on success PEAR_Error on connection failure.
      */
     function init()
@@ -111,18 +112,17 @@ class Net_IMSP {
             return $result;
         }
         $this->writeToLog('Initializing Net_IMSP object.', __FILE__, __LINE__,
-                          PEAR_LOG_DEBUG);
+                          PEAR_LOG_INFO);
         return true;
     }
 
     /**
      * Logs out of the server and closes the IMSP stream
-     *
-     *@access public
      */
     function logout()
     {
-        $this->writeToLog('Closing Connection.');
+        $this->writeToLog('Closing IMSP Connection.', __FILE__, __LINE__,
+                          PEAR_LOG_INFO);
         $command_string = 'LOGOUT';
         $result = $this->imspSend($command_string);
         if (is_a($result, 'PEAR_Error')) {
@@ -137,7 +137,6 @@ class Net_IMSP {
     /**
      * Returns the raw capability response from the server.
      *
-     * @access public
      * @return string  The raw capability response.
      */
     function capability()
@@ -157,7 +156,8 @@ class Net_IMSP {
                     return $this->imspError(IMSP_UNEXPECTED_RESPONSE,
                                             __FILE__, __LINE__);
                 } else {
-                    $this->writeToLog('CAPABILITY completed OK');
+                    $this->writeToLog('CAPABILITY completed OK', __FILE__,
+                                      __LINE__, PEAR_LOG_INFO);
                     return $capability;
                 }
             }
@@ -167,7 +167,6 @@ class Net_IMSP {
     /**
      * Attempts to open an IMSP socket with the server.
      *
-     * @access public
      * @return mixed  True on success PEAR_Error on failure.
      */
     function imspOpen()
@@ -189,7 +188,6 @@ class Net_IMSP {
     /**
      * Attempts to send a command to the server.
      *
-     * @access public
      * @param string  $commandText Text to send to the server.
      * @param boolean $includeTag  Determines if command tag is prepended.
      * @param boolean  $sendCRLF   Determines if CRLF is appended.
@@ -199,8 +197,8 @@ class Net_IMSP {
     {
         $command_text = '';
 
-        if (!$this->_stream){
-            return $this->imspError(IMSP_CONNECTION_FAILURE,__FILE__,__LINE__);
+        if (!$this->_stream) {
+            return $this->imspError(IMSP_CONNECTION_FAILURE, __FILE__, __LINE__);
         }
 
         if ($includeTag) {
@@ -227,12 +225,11 @@ class Net_IMSP {
     /**
      * Receives a single CRLF terminated server response string
      *
-     * @access public
      * @return mixed 'NO', 'BAD', 'OK', raw response or PEAR_Error.
      */
     function imspReceive()
     {
-        if (!$this->_stream){
+        if (!$this->_stream) {
             return $this->imspError(IMSP_CONNECTION_FAILURE, __FILE__, __LINE__);
         }
         $result = fgets($this->_stream, IMSP_DEFAULT_RESPONSE_LENGTH);
@@ -288,7 +285,6 @@ class Net_IMSP {
      * Retrieves CRLF terminated response from server and splits it into
      * an array delimited by a <space>.
      *
-     * @access public
      * @return array result from split().
      */
     function getServerResponseChunks()
@@ -303,9 +299,9 @@ class Net_IMSP {
      * Receives fixed number of bytes from imsp socket. Used when
      * server returns a string literal.
      *
-     * @access public
-     * @param int $length Number of bytes to read from socket.
-     * @return string Text of string literal.
+     * @param integer $length  Number of bytes to read from socket.
+     *
+     * @return string  Text of string literal.
      */
     function receiveStringLiteral($length)
     {
@@ -328,10 +324,8 @@ class Net_IMSP {
     }
 
     /**
-     * Determines if a string needs to be quoted before sending to the
-     * server.
+     * Determines if a string needs to be quoted before sending to the server.
      *
-     * @access public
      * @param string $string  String to be tested.
      * @return string Original string quoted if needed.
      */
@@ -348,10 +342,9 @@ class Net_IMSP {
      * Raises an 'imsp' error.  Basically, only writes
      * error out to the horde logfile and returns PEAR_Error
      *
-     * @param string $err  Either a PEAR_Error object or
-     *                     text to write to log.
-     * @param string $file File name where error occured.
-     * @param int    $line Line number where error occured.
+     * @param string $err    Either PEAR_Error object or text to write to log.
+     * @param string $file   File name where error occured.
+     * @param integer $line  Line number where error occured.
      */
     function imspError($err = '', $file=__FILE__, $line=__LINE__)
     {
@@ -372,11 +365,10 @@ class Net_IMSP {
     /**
      * Writes a message to the imsp logfile.
      *
-     * @access public
-     * @param string $message Text to write.
+     * @param string $message  Text to write.
      */
-    function writeToLog($message, $file=__FILE__,
-                        $line=__LINE__, $priority=PEAR_LOG_INFO)
+    function writeToLog($message, $file = __FILE__,
+                        $line = __LINE__, $priority = PEAR_LOG_INFO)
     {
         if (($this->logEnabled) && ($this->_logSet)) {
             if ($priority > $this->_logLevel) {
@@ -397,7 +389,6 @@ class Net_IMSP {
     /**
      * Creates a new Log object based on $params
      *
-     * @access public
      * @param  array  $params Log object parameters.
      * @return mixed  True on success or PEAR_Error on failure.
      */
@@ -440,7 +431,6 @@ class Net_IMSP {
      * Attempts to create a Net_IMSP object based on $driver.
      * Must be called as $imsp = &Net_IMSP::factory($driver, $params);
      *
-     * @access public
      * @param  string $driver Type of Net_IMSP object to return.
      * @param  mixed  $params  Any parameters needed by the Net_IMSP object.
      * @return mixed  The requested Net_IMSP object or PEAR_Error on failure.
