@@ -25,7 +25,7 @@ if (!function_exists('_')) {
  * The Horde_Test:: class provides functions used in the test scripts
  * used in the various applications (test.php).
  *
- * $Horde: horde/lib/Test.php,v 1.31.4.11.2.1 2005/10/19 23:01:17 slusarz Exp $
+ * $Horde: horde/lib/Test.php,v 1.31.4.11.2.3 2006/03/28 12:33:32 jan Exp $
  *
  * Copyright 1999-2005 Charles J. Hagenbuch <chuck@horde.org>
  * Copyright 1999-2005 Jon Parise <jon@horde.org>
@@ -546,6 +546,10 @@ FOOTER;
         if ($output->major < '4.3') {
             $output->status = 'This version of PHP is not supported. You need to upgrade to a more recent version.';
             $vers_check = false;
+        } elseif (($output->major == '5.1') ||
+                  ($output->major == '5.0' && $output->minor >= 4)) {
+            $output->status = 'This version of PHP is not supported. You need to downgrade to an older version (< 5.0.4).';
+            $output->status_color = 'red';
         } elseif (($output->major == '4.3') ||
                   ($output->major == '4.4') ||
                   ($output->major == '5.0')) {
@@ -582,11 +586,10 @@ FOOTER;
                 ($det['status'] != 'block') &&
                 is_readable($det['fileroot'] . '/lib/version.php')) {
                 require_once $det['fileroot'] . '/lib/version.php';
-                eval('$defined = defined(\'' . strtoupper($mod) . '_VERSION\');');
-                if ($defined) {
-                    eval('$ver = ' . strtoupper($mod) . '_VERSION;');
+                $version_constant = String::upper($mod) . '_VERSION';
+                if (defined($version_constant)) {
                     $this->_appoutput[$mod] = &new stdClass;
-                    $this->_appoutput[$mod]->version = $ver;
+                    $this->_appoutput[$mod]->version = constant($version_constant);
                     if (($mod != 'horde') &&
                         @is_readable($det['fileroot'] . '/test.php')) {
                         $this->_appoutput[$mod]->test = $det['webroot'] . '/test.php';
