@@ -2,7 +2,7 @@
 /**
  * Class for providing garbage collection for any VFS instance.
  *
- * $Horde: framework/VFS/VFS/GC.php,v 1.4.12.1 2005/01/03 12:19:20 jan Exp $
+ * $Horde: framework/VFS/VFS/GC.php,v 1.4.12.6 2005/07/03 04:52:42 selsky Exp $
  *
  * Copyright 2003-2005 Michael Slusarz <slusarz@bigworm.colorado.edu>
  *
@@ -10,7 +10,6 @@
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Michael Slusarz <slusarz@bigworm.colorado.edu>
- * @version $Revision: 1.4.12.1 $
  * @since   Horde 3.0
  * @package VFS
  */
@@ -19,19 +18,17 @@ class VFS_GC {
     /**
      * Garbage collect files in the VFS storage system.
      *
-     * @access public
-     *
-     * @param object VFS &$vfs        The VFS object to perform
-     *                                garbage collection on.
-     * @param string $path            The VFS path to clean.
-     * @param optional integer $secs  The minimum amount of time (in seconds)
-     *                                required before a file is removed.
+     * @param VFS &$vfs      The VFS object to perform garbage collection on.
+     * @param string $path   The VFS path to clean.
+     * @param integer $secs  The minimum amount of time (in seconds) required
+     *                       before a file is removed.
      */
     function gc(&$vfs, $path, $secs = 345600)
     {
         /* A 1% chance we will run garbage collection during a call. */
         if (rand(0, 99) == 0) {
-            $files = $vfs->listFolder($path);
+            /* Make sure cleaning is done recursively. */
+            $files = $vfs->listFolder($path, null, true, false, true);
             if (!is_a($files, 'PEAR_Error') && is_array($files)) {
                 $modtime = time() - $secs;
                 foreach ($files as $val) {
