@@ -3,7 +3,7 @@
 /**
  * Strategy for directly writing output file to VFS.
  *
- * $Horde: framework/VFS_ISOWriter/ISOWriter/RealOutputStrategy/direct.php,v 1.1.8.1 2005/01/03 12:19:21 jan Exp $
+ * $Horde: framework/VFS_ISOWriter/ISOWriter/RealOutputStrategy/direct.php,v 1.1.8.3 2005/08/24 14:04:39 selsky Exp $
  *
  * Copyright 2004-2005 Cronosys, LLC <http://www.cronosys.com/>
  *
@@ -11,7 +11,6 @@
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Jason M. Felice <jfelice@cronosys.com>
- * @version $Revision: 1.1.8.1 $
  * @package VFS_ISO
  * @since   Horde 3.0
  */
@@ -28,7 +27,7 @@ class VFS_ISOWriter_RealOutputStrategy_direct extends VFS_ISOWriter_RealOutputSt
         $dir = dirname($filename);
         while (!@is_dir($dir)) {
             if (!@mkdir($dir, 0755)) {
-                return PEAR::raiseError(sprintf(_("Could not mkdir '%s'."),
+                return PEAR::raiseError(sprintf(_("Could not mkdir \"%s\"."),
                                                 $dir));
             }
             $dir = dirname($dir);
