@@ -6,7 +6,7 @@
  * For usage information call:
  * ./translation.php help
  *
- * $Horde: horde/po/translation.php,v 1.91.2.1 2005/01/23 12:08:35 jan Exp $
+ * $Horde: horde/po/translation.php,v 1.91.2.8.2.1 2006/03/28 12:33:33 jan Exp $
  */
 
 function footer()
@@ -273,7 +273,7 @@ function xtract()
         chdir($dirs[$i]);
         if ($apps[$i] == 'horde') {
             $files = search_ext('php', '.', true);
-            foreach(array('admin', 'framework', 'lib', 'services', 'templates', 'util', 'config' . DS . 'themes') as $search_dir) {
+            foreach (array('admin', 'framework', 'lib', 'services', 'templates', 'util', 'config' . DS . 'themes') as $search_dir) {
                 $files = array_merge($files, search_ext('(php|inc|js)', $search_dir));
             }
             $files = array_merge($files, search_ext('dist', 'config'));
@@ -305,7 +305,7 @@ function xtract()
             $files = array_filter($files, create_function('$file', 'return substr($file, 0, 9) != "." . DS . "config" . DS;'));
             $files = array_merge($files, search_ext('dist', 'config'));
             $sh = $GLOBALS['xgettext'] . ' --language=' . $language .
-                  ' --keyword=_ --sort-output --copyright-holder="Horde Project"';
+                  ' --keyword=_ --sort-output --force-po --copyright-holder="Horde Project"';
             if ($gettext_version[0] > 0 || $gettext_version[1] > 11) {
                 $sh .= ' --msgid-bugs-address="dev@lists.horde.org"';
             }
@@ -422,7 +422,7 @@ function merge()
         if (!empty($module) && $module != $apps[$i]) {
             continue;
         }
-        $c->writeln(sprintf(_("Merging translation for module %s..."), $apps[$i]));
+        $c->writeln(sprintf(_("Merging translation for module %s..."), $c->bold($apps[$i])));
         $dir = $dirs[$i] . DS . 'po' . DS;
         if (empty($lang)) {
             $langs = get_languages($dirs[$i]);
@@ -578,7 +578,7 @@ function init()
         $package = ucfirst($apps[$i]);
         $package_u = String::upper($apps[$i]);
         @include $dirs[$i] . '/lib/version.php';
-        $version = eval('return(defined("' . $package_u . '_VERSION") ? ' . $package_u . '_VERSION : "???");');
+        $version = defined($package_u . '_VERSION') ? constant($package_u . '_VERSION') : '???';
         echo sprintf(_("Initializing module %s... "), $apps[$i]);
         if (!@file_exists($dirs[$i] . '/po/' . $apps[$i] . '.pot')) {
             $c->writeln($c->red(_("failed")));
@@ -881,11 +881,12 @@ function cleanup($keep_untranslated = false)
             } else {
                 exec($sh, $out, $ret);
             }
-            @unlink($pofile);
-            rename($pofile . '.tmp', $pofile);
             if ($ret == 0) {
+                @unlink($pofile);
+                rename($pofile . '.tmp', $pofile);
                 $c->writeln($c->green(_("done")));
             } else {
+                @unlink($pofile . '.tmp', $pofile);
                 $c->writeln($c->red(_("failed")));
             }
             $c->writeln();
@@ -924,6 +925,13 @@ function commit($help_only = false)
     $files = array();
     for ($i = 0; $i < count($dirs); $i++) {
         if (!empty($module) && $module != $apps[$i]) continue;
+        if ($apps[$i] == 'horde') {
+            $dirs[] = $dirs[$i] . DS . 'admin';
+            $apps[] = 'horde/admin';
+            if (!empty($module)) {
+                $module = 'horde/admin';
+            }
+        }
         if (empty($lang)) {
             if ($help_only) {
                 $files = array_merge($files, strip_horde(search_ext('xml', $dirs[$i] . DS . 'locale')));
@@ -932,17 +940,15 @@ function commit($help_only = false)
                 $files = array_merge($files, strip_horde(search_file('^[a-z]{2}_[A-Z]{2}', $dirs[$i] . DS . 'locale', true)));
             }
         } else {
-            if (!@file_exists($dirs[$i] . '/po/' . $lang . '.po')) continue;
             if ($help_only) {
-                $file = $dirs[$i] . DS . 'locale' . DS . $lang . DS . 'help.xml';
-                if (!@file_exists($file)) continue;
-                $files[] = strip_horde($file);
+                if (!@file_exists($dirs[$i] . DS . 'locale' . DS . $lang . DS . 'help.xml')) continue;
             } else {
+                if (!@file_exists($dirs[$i] . '/po/' . $lang . '.po')) continue;
                 $files[] = strip_horde($dirs[$i] . DS . 'po' . DS . $lang . '.po');
-                $files[] = strip_horde($dirs[$i] . DS . 'locale' . DS . $lang);
             }
+            $files[] = strip_horde($dirs[$i] . DS . 'locale' . DS . $lang);
         }
-        if ($docs && !$help_only) {
+        if ($docs && !$help_only && $apps[$i]) {
             $files[] = strip_horde($dirs[$i] . DS . 'docs');
             if ($apps[$i] == 'horde') {
                 $horde_conf = $dirs[array_search('horde', $dirs)] . DS . 'config' . DS;
@@ -965,12 +971,11 @@ function commit($help_only = false)
             foreach ($files as $file) {
                 if (strstr($file, 'locale')) {
                     if ($help_only) {
-                        $add = $file . DS . '*.xml';
-                        $sh .= ' ' . $add;
-                        $c->writeln($add);
+                        $sh .= ' ' . $file . DS . '*.xml';
+                        $c->writeln($file . DS . '*.xml');
                     } else {
                         $sh .= ' ' . $file . DS . '*.xml ' . $file . DS . 'LC_MESSAGES';
-                        $c->writeln($file . DS . "*.xml\n$file" . DS . 'LC_MESSAGES ');
+                        $c->writeln($file . DS . "*.xml\n$file" . DS . 'LC_MESSAGES');
                     }
                 }
             }
@@ -1038,6 +1043,13 @@ function update_help()
     for ($i = 0; $i < count($dirs); $i++) {
         if (!empty($module) && $module != $apps[$i]) { continue; }
         if (!is_dir("$dirs[$i]/locale")) continue;
+        if ($apps[$i] == 'horde') {
+            $dirs[] = $dirs[$i] . DS . 'admin';
+            $apps[] = 'horde/admin';
+            if (!empty($module)) {
+                $module = 'horde/admin';
+            }
+        }
         if (empty($lang)) {
             $files = search_file('help.xml', $dirs[$i] . DS . 'locale');
         } else {
@@ -1190,6 +1202,13 @@ function make_help()
     for ($i = 0; $i < count($dirs); $i++) {
         if (!empty($module) && $module != $apps[$i]) continue;
         if (!is_dir("$dirs[$i]/locale")) continue;
+        if ($apps[$i] == 'horde') {
+            $dirs[] = $dirs[$i] . DS . 'admin';
+            $apps[] = 'horde/admin';
+            if (!empty($module)) {
+                $module = 'horde/admin';
+            }
+        }
         if (empty($lang)) {
             $files = search_file('help.xml', $dirs[$i] . DS . 'locale');
         } else {
@@ -1200,6 +1219,11 @@ function make_help()
             continue;
         }
         foreach ($files as $file_loc) {
+            if (!@file_exists($file_loc)) {
+                $c->writeln(_("Skipped..."));
+                $c->writeln();
+                continue;
+            }
             $locale = substr($file_loc, 0, strrpos($file_loc, DS));
             $locale = substr($locale, strrpos($locale, DS) + 1);
             if ($locale == 'en_US') continue;
@@ -1244,7 +1268,7 @@ function make_help()
                 $count_all++;
                 $id = $entry->get_attribute('id');
                 if (!array_key_exists($id, $md5_en)) {
-                    $c->writeln(wordwrap($c->red(_("Warning: ")) . sprintf(_("No entry with the id '%s' exists in the original help file."), $id)));
+                    $c->writeln(wordwrap($c->red(_("Warning: ")) . sprintf(_("No entry with the id \"%s\" exists in the original help file."), $id)));
                 } else {
                     $entry->set_attribute('md5', $md5_en[$id]);
                     $entry->set_attribute('state', 'uptodate');
@@ -1398,7 +1422,7 @@ $options_list = array(
     'commit-help'=> array('hl:m:nM:', array('module=', 'locale=', 'new', 'message=')),
     'compendium' => array('hl:d:a:', array('locale=', 'directory=', 'add=')),
     'extract'    => array('hm:', array('module=')),
-    'init'       => array('hl:m:n', array('module=', 'locale=', 'no-compendium')),
+    'init'       => array('hl:m:nc:', array('module=', 'locale=', 'no-compendium', 'compendium=')),
     'merge'      => array('hl:m:c:n', array('module=', 'locale=', 'compendium=', 'no-compendium')),
     'make'       => array('hl:m:c:ns', array('module=', 'locale=', 'compendium=', 'no-compendium', 'statistics')),
     'make-help'  => array('hl:m:', array('module=', 'locale=')),
